@@ -25,11 +25,17 @@ impl Interpreter {
     pub fn get_name(&self) -> String { return self.file_name.clone();}
     /// Interpreter execution function
     pub fn run(&mut self) -> i32 {
-        println!("{}:", self.file_name);
-        let lexer_result = self.parser.lex();
-        match lexer_result {
+        //println!("{}:", self.file_name);
+        let parser_result = self.parser.parse();
+        //println!("{:?}", parser_result);
+        match parser_result {
             Ok(_) => 0,
-            Err(_) => 1,
+            Err(vec) => {
+                for e in vec {
+                    println!("{}", e);
+                }
+                return 1;
+            },
         }
     }
 }
\ No newline at end of file
